yakumo.neutron.v2.lbaas.health_monitor

Package yakumo :: Package neutron :: Package v2 :: Package lbaas :: Module health_monitor |
[hide private]
[frames] | no frames]

# Module health_monitor

source code

Resource class and its manager for LBaaS Health Monitors in Networking V2 API

Classes | [hide private]
| Resource Resource class for LBaaS Health Monitors in Networking V2 API
| Manager Manager class for LBaaS Health Monitors in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.neutron.v2.lbaas``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('pools', 'pools', <yakumo.mapper.List object at 0x7f1333c44350>),
       ('type', 'type', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('http_method',
        'http_method',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('url_path',
        'url_path',
      ...